@@ -10,7 +10,7 @@ BEGIN {
 }
 use Config ();
 
-our $VERSION = '2.000_025';
+our $VERSION = '2.000_026';
 $VERSION =~ tr/_//d;
 
 BEGIN {
@@ -71,8 +71,8 @@ sub _cwd {
     goto &$cwd;
   }
   my $drive = shift;
-  return Win32::Cwd()
-    if _WIN32 && defined &Win32::Cwd && !$drive;
+  return Win32::GetCwd()
+    if _WIN32 && defined &Win32::GetCwd && !$drive;
   local @ENV{qw(PATH IFS CDPATH ENV BASH_ENV)};
   my $cmd = $drive ? "eval { Cwd::getdcwd(q($drive)) }"
                    : 'getcwd';
@@ -594,7 +594,7 @@ sub build_fish_env_declaration {
   # really care about PATH, but might as well make this routine more general.
   if ($name =~ /^(?:CD|MAN)?PATH$/) {
     $value =~ s/$_path_sep/ /g;
-    my $silent = $name =~ /^(?:CD)?PATH$/ ? " ^"._devnull : '';
+    my $silent = $name =~ /^(?:CD)?PATH$/ ? " 2>"._devnull : '';
     return qq{set -x $name $value$silent;\n};
   }
 
